@@ -6,7 +6,6 @@ import (
 	"path/filepath"
 	"runtime"
 	"runtime/debug"
-	"strings"
 	"time"
 
 	"github.com/pkg/errors"
@@ -135,5 +134,5 @@ func Commit() string {
 }
 
 func UserAgent() string {
-	return strings.TrimSpace(fmt.Sprintf("fly-cli/%s", Version()))
+	return fmt.Sprintf("flyctl/%s", Version())
 }
